==> org.eclipse.ocl.examples.xtext.base.source_3.3.1.v20130817-0929.jar: org/eclipse/ocl/examples/xtext/base/attributes/TemplateSignatureCSAttribution.java <==
/**
 * <copyright>
 *
 * Copyright (c) 2010, 2012 E.D.Willink and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     E.D.Willink - initial API and implementation
 *
 * </copyright>
 *
 * $Id: TemplateSignatureCSAttribution.java,v 1.2 2011/01/24 21:00:31 ewillink Exp $
 */
package org.eclipse.ocl.examples.xtext.base.attributes;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.ocl.examples.pivot.TemplateSignature;
import org.eclipse.ocl.examples.pivot.scoping.AbstractAttribution;
import org.eclipse.ocl.examples.pivot.scoping.EnvironmentView;
import org.eclipse.ocl.examples.pivot.scoping.ScopeView;
import org.eclipse.ocl.examples.pivot.utilities.PivotUtil;
import org.eclipse.ocl.examples.xtext.base.baseCST.TemplateSignatureCS;

public class TemplateSignatureCSAttribution extends AbstractAttribution
{
	public static final TemplateSignatureCSAttribution INSTANCE = new TemplateSignatureCSAttribution();

	@Override
	public ScopeView computeLookup(@NonNull EObject target, @NonNull EnvironmentView environmentView, @NonNull ScopeView scopeView) {
		TemplateSignatureCS targetElement = (TemplateSignatureCS)target;
		TemplateSignature pivot = PivotUtil.getPivot(TemplateSignature.class, targetElement);
		if (pivot != null) {
			environmentView.addElements(pivot.getOwnedParameter());
		}
		return scopeView.getParent();
	}
}

==> org.eclipse.ocl.examples.xtext.base.source_3.4.0.v20140602-1102.jar: org/eclipse/ocl/examples/xtext/base/attributes/TemplateSignatureCSAttribution.java <==
/*******************************************************************************
 * Copyright (c) 2010, 2012 E.D.Willink and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     E.D.Willink - initial API and implementation
 *******************************************************************************/
package org.eclipse.ocl.examples.xtext.base.attributes;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.ocl.examples.pivot.TemplateSignature;
import org.eclipse.ocl.examples.pivot.scoping.AbstractAttribution;
import org.eclipse.ocl.examples.pivot.scoping.EnvironmentView;
import org.eclipse.ocl.examples.pivot.scoping.ScopeView;
import org.eclipse.ocl.examples.pivot.utilities.PivotUtil;
import org.eclipse.ocl.examples.xtext.base.basecs.TemplateSignatureCS;

public class TemplateSignatureCSAttribution extends AbstractAttribution
{
	public static final TemplateSignatureCSAttribution INSTANCE = new TemplateSignatureCSAttribution();

	@Override
	public ScopeView computeLookup(@NonNull EObject target, @NonNull EnvironmentView environmentView, @NonNull ScopeView scopeView) {
		TemplateSignatureCS targetElement = (TemplateSignatureCS)target;
		TemplateSignature pivot = PivotUtil.getPivot(TemplateSignature.class, targetElement);
		if (pivot != null) {
			environmentView.addElements(pivot.getOwnedParameter());
		}
		return scopeView.getParent();
	}
}
